@@ -1,24 +1,28 @@
 /*
  * SPDX-FileCopyrightText: (C) 2020 Carl Schwan <carl@carlschwan.eu>
+ * SPDX-FileCopyrightText: (C) 2022 Vlad Rakhmanin <vladimir.rakhmanin@ucdconnect.ie>
  *
- * SPDX-LicenseRef: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #include "kontrast.h"
 
-#include <QtMath>
+#include <QDebug>
 #include <QRandomGenerator>
+#include <QtMath>
+
+#include <KLocalizedString>
+
+#ifdef QT_DBUS_LIB
+#include <QDBusConnection>
 #include <QDBusMessage>
 #include <QDBusMetaType>
+#include <QDBusObjectPath>
 #include <QDBusPendingCall>
 #include <QDBusPendingCallWatcher>
 #include <QDBusPendingReply>
-#include <QDBusObjectPath>
-#include <QDBusConnection>
-#include <QDebug>
 
-
-QDBusArgument &operator <<(QDBusArgument &arg, const Kontrast::ColorRGB &color)
+QDBusArgument &operator<<(QDBusArgument &arg, const Kontrast::ColorRGB &color)
 {
     arg.beginStructure();
     arg << color.red << color.green << color.blue;
@@ -26,7 +30,7 @@ QDBusArgument &operator <<(QDBusArgument &arg, const Kontrast::ColorRGB &color)
     return arg;
 }
 
-const QDBusArgument &operator >>(const QDBusArgument &arg, Kontrast::ColorRGB &color)
+const QDBusArgument &operator>>(const QDBusArgument &arg, Kontrast::ColorRGB &color)
 {
     double red, green, blue;
     arg.beginStructure();
@@ -38,15 +42,18 @@ const QDBusArgument &operator >>(const QDBusArgument &arg, Kontrast::ColorRGB &c
 
     return arg;
 }
-
+#endif
 
 Kontrast::Kontrast(KAboutData about, QObject *parent)
     : QObject(parent)
+    , m_fontSize(12)
     , m_about(about)
 {
     setObjectName(QStringLiteral("Kontrast"));
 
+#ifdef QT_DBUS_LIB
     qDBusRegisterMetaType<ColorRGB>();
+#endif
 }
 
 QColor Kontrast::textColor() const
@@ -63,6 +70,7 @@ void Kontrast::setTextColor(const QColor textColor)
     m_textColor = textColor;
     Q_EMIT textColorChanged();
     Q_EMIT contrastChanged();
+    Q_EMIT fontSizeChanged();
 }
 
 int Kontrast::textHue() const
@@ -78,6 +86,7 @@ void Kontrast::setTextHue(int hue)
     m_textColor.setHsl(hue, m_textColor.hslSaturation(), m_textColor.lightness());
     Q_EMIT textColorChanged();
     Q_EMIT contrastChanged();
+    Q_EMIT fontSizeChanged();
 }
 
 int Kontrast::textLightness() const
@@ -93,6 +102,7 @@ void Kontrast::setTextLightness(int lightness)
     m_textColor.setHsl(m_textColor.hslHue(), m_textColor.hslSaturation(), lightness);
     Q_EMIT textColorChanged();
     Q_EMIT contrastChanged();
+    Q_EMIT fontSizeChanged();
 }
 
 int Kontrast::textSaturation() const
@@ -108,6 +118,21 @@ void Kontrast::setTextSaturation(int saturation)
     m_textColor.setHsl(m_textColor.hslHue(), saturation, m_textColor.lightness());
     Q_EMIT textColorChanged();
     Q_EMIT contrastChanged();
+    Q_EMIT fontSizeChanged();
+}
+
+int Kontrast::fontSize() const
+{
+    return m_fontSize;
+}
+
+void Kontrast::setFontSize(int fontSize)
+{
+    if (m_fontSize == fontSize) {
+        return;
+    }
+    m_fontSize = fontSize;
+    Q_EMIT fontSizeChanged();
 }
 
 QColor Kontrast::backgroundColor() const
@@ -124,6 +149,7 @@ void Kontrast::setBackgroundColor(const QColor backgroundColor)
     m_backgroundColor = backgroundColor;
     Q_EMIT backgroundColorChanged();
     Q_EMIT contrastChanged();
+    Q_EMIT fontSizeChanged();
 }
 
 int Kontrast::backgroundHue() const
@@ -139,6 +165,7 @@ void Kontrast::setBackgroundHue(int hue)
     m_backgroundColor.setHsl(hue, m_backgroundColor.hslSaturation(), m_backgroundColor.lightness());
     Q_EMIT backgroundColorChanged();
     Q_EMIT contrastChanged();
+    Q_EMIT fontSizeChanged();
 }
 
 int Kontrast::backgroundLightness() const
@@ -154,6 +181,7 @@ void Kontrast::setBackgroundLightness(int lightness)
     m_backgroundColor.setHsl(m_backgroundColor.hslHue(), m_backgroundColor.hslSaturation(), lightness);
     Q_EMIT backgroundColorChanged();
     Q_EMIT contrastChanged();
+    Q_EMIT fontSizeChanged();
 }
 
 int Kontrast::backgroundSaturation() const
@@ -169,6 +197,7 @@ void Kontrast::setBackgroundSaturation(int saturation)
     m_backgroundColor.setHsl(m_backgroundColor.hslHue(), saturation, m_backgroundColor.lightness());
     Q_EMIT backgroundColorChanged();
     Q_EMIT contrastChanged();
+    Q_EMIT fontSizeChanged();
 }
 
 qreal luminosity(const QColor color)
@@ -178,9 +207,9 @@ qreal luminosity(const QColor color)
     const qreal green = color.greenF();
     const qreal blue = color.blueF();
 
-    const qreal redLum = (red <= 0.03928) ? red / 12.92 : qPow(((red + 0.055) /  1.055), 2.4);
-    const qreal greenLum = (green <= 0.03928) ? green / 12.92 : qPow(((green + 0.055) /  1.055), 2.4);
-    const qreal blueLum = (blue <= 0.03928) ? blue / 12.92 : qPow(((blue + 0.055) /  1.055), 2.4);
+    const qreal redLum = (red <= 0.03928) ? red / 12.92 : qPow(((red + 0.055) / 1.055), 2.4);
+    const qreal greenLum = (green <= 0.03928) ? green / 12.92 : qPow(((green + 0.055) / 1.055), 2.4);
+    const qreal blueLum = (blue <= 0.03928) ? blue / 12.92 : qPow(((blue + 0.055) / 1.055), 2.4);
 
     return 0.2126 * redLum + 0.7152 * greenLum + 0.0722 * blueLum;
 }
@@ -206,6 +235,7 @@ void Kontrast::random()
     Q_EMIT backgroundColorChanged();
     Q_EMIT textColorChanged();
     Q_EMIT contrastChanged();
+    Q_EMIT fontSizeChanged();
 }
 
 void Kontrast::reverse()
@@ -216,6 +246,7 @@ void Kontrast::reverse()
     Q_EMIT backgroundColorChanged();
     Q_EMIT textColorChanged();
     Q_EMIT contrastChanged();
+    Q_EMIT fontSizeChanged();
 }
 
 QColor Kontrast::displayTextColor() const
@@ -242,6 +273,7 @@ QColor Kontrast::pixelAt(const QImage &image, int x, int y) const
 
 void Kontrast::grabColor()
 {
+#ifdef QT_DBUS_LIB
     QDBusMessage message = QDBusMessage::createMethodCall(QLatin1String("org.freedesktop.portal.Desktop"),
                                                           QLatin1String("/org/freedesktop/portal/desktop"),
                                                           QLatin1String("org.freedesktop.portal.Screenshot"),
@@ -249,7 +281,7 @@ void Kontrast::grabColor()
     message << QLatin1String("x11:") << QVariantMap{};
     QDBusPendingCall pendingCall = QDBusConnection::sessionBus().asyncCall(message);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(pendingCall);
-    connect(watcher, &QDBusPendingCallWatcher::finished, [this] (QDBusPendingCallWatcher *watcher) {
+    connect(watcher, &QDBusPendingCallWatcher::finished, [this](QDBusPendingCallWatcher *watcher) {
         QDBusPendingReply<QDBusObjectPath> reply = *watcher;
         if (reply.isError()) {
             qWarning() << "Couldn't get reply";
@@ -263,6 +295,7 @@ void Kontrast::grabColor()
                                                   SLOT(gotColorResponse(uint, QVariantMap)));
         }
     });
+#endif
 }
 
 QColor Kontrast::grabbedColor() const
@@ -270,15 +303,63 @@ QColor Kontrast::grabbedColor() const
     return m_grabbedColor;
 }
 
-void Kontrast::gotColorResponse(uint response, const QVariantMap& results)
+void Kontrast::gotColorResponse(uint response, const QVariantMap &results)
 {
+#ifdef QT_DBUS_LIB
     if (!response) {
         if (results.contains(QLatin1String("color"))) {
             auto color = qdbus_cast<ColorRGB>(results.value(QLatin1String("color")));
             m_grabbedColor = QColor(color.red * 256, color.green * 256, color.blue * 256);
-            emit grabbedColorChanged();
+            Q_EMIT grabbedColorChanged();
         }
     } else {
         qWarning() << "Failed to take screenshot";
     }
+#else
+    Q_UNUSED(response);
+    Q_UNUSED(results);
+#endif
+}
+
+Kontrast::ContrastQualities Kontrast::getContrastQualities()
+{
+    const qreal contrast = Kontrast::contrast();
+
+    if (contrast > 7.0) {
+        return ContrastQualities{Perfect, Perfect, Perfect};
+    } else if (contrast > 4.5) {
+        return ContrastQualities{Good, Good, Perfect};
+    } else if (contrast > 3.0) {
+        return ContrastQualities{Bad, Bad, Good};
+    } else {
+        return ContrastQualities{Bad, Bad, Bad};
+    }
+}
+
+QString Kontrast::getFontSizeQualityLabel()
+{
+    const auto currentQualities = getContrastQualities();
+
+    Quality currentQuality; 
+    if (m_fontSize >= 18) {
+        currentQuality = currentQualities.large;
+    } else if (m_fontSize > 13) {
+        currentQuality = currentQualities.medium;
+    } else {
+        currentQuality = currentQualities.small;
+    }
+
+    QString fontSizeQualityLabel;
+    switch (currentQuality) {
+    case Bad:
+        fontSizeQualityLabel = i18n("Font size %1px is bad with the current contrast", m_fontSize);
+        break;
+    case Good:
+        fontSizeQualityLabel = i18n("Font size %1px is good with the current contrast", m_fontSize);
+        break;
+    case Perfect:
+        fontSizeQualityLabel = i18n("Font size %1px is perfect with the current contrast", m_fontSize);
+        break;
+    }
+    return fontSizeQualityLabel;
 }
