@@ -1,7 +1,8 @@
 /*
  * SPDX-FileCopyrightText: (C) 2020 Carl Schwan <carl@carlschwan.eu>
+ * SPDX-FileCopyrightText: (C) 2022 Vlad Rakhmanin <vladimir.rakhmanin@ucdconnect.ie>
  *
- * SPDX-LicenseRef: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #pragma once
@@ -26,12 +27,16 @@ class Kontrast : public QObject
 
     Q_PROPERTY(int textLightness READ textLightness WRITE setTextLightness NOTIFY textColorChanged)
 
+    Q_PROPERTY(int fontSize READ fontSize WRITE setFontSize NOTIFY fontSizeChanged)
+
     Q_PROPERTY(QColor backgroundColor READ backgroundColor WRITE setBackgroundColor NOTIFY backgroundColorChanged)
 
     Q_PROPERTY(int backgroundHue READ backgroundHue WRITE setBackgroundHue NOTIFY backgroundColorChanged)
 
     Q_PROPERTY(int backgroundSaturation READ backgroundSaturation WRITE setBackgroundSaturation NOTIFY backgroundColorChanged)
 
+    Q_PROPERTY(QString fontSizeLabel READ getFontSizeQualityLabel NOTIFY fontSizeChanged)
+
     Q_PROPERTY(int backgroundLightness READ backgroundLightness WRITE setBackgroundLightness NOTIFY backgroundColorChanged)
 
     Q_PROPERTY(qreal contrast READ contrast NOTIFY contrastChanged)
@@ -46,6 +51,16 @@ public:
     Kontrast(KAboutData about, QObject *parent = nullptr);
     virtual ~Kontrast() override = default;
 
+    enum Quality { Bad, Good, Perfect };
+
+    Q_ENUM(Quality)
+
+    struct ContrastQualities {
+        Quality small;
+        Quality medium;
+        Quality large;
+    };
+
     struct ColorRGB {
         double red;
         double green;
@@ -64,6 +79,9 @@ public:
     int textLightness() const;
     void setTextLightness(int lightness);
 
+    int fontSize() const;
+    void setFontSize(int fontSize);
+
     QColor backgroundColor() const;
     void setBackgroundColor(const QColor backgroundColor);
 
@@ -84,6 +102,8 @@ public:
 
     QColor grabbedColor() const;
 
+    QString getFontSizeQualityLabel();
+
     Q_INVOKABLE void random();
     Q_INVOKABLE void reverse();
     Q_INVOKABLE void grabColor();
@@ -97,12 +117,16 @@ Q_SIGNALS:
     void backgroundColorChanged();
     void contrastChanged();
     void grabbedColorChanged();
+    void fontSizeChanged();
 
 private:
     QColor m_textColor;
     QColor m_backgroundColor;
     QColor m_grabbedColor;
+    int m_fontSize;
     KAboutData m_about;
+
+    ContrastQualities getContrastQualities();
 };
 
 Q_DECLARE_METATYPE(Kontrast::ColorRGB)
