@@ -1,7 +1,7 @@
 /*
  * SPDX-FileCopyrightText: (C) 2020 Carl Schwan <carl@carlschwan.eu>
  *
- * SPDX-LicenseRef: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 #include "config-kontrast.h"
 #include "savedcolormodel.h"
@@ -14,13 +14,14 @@
 #include <QGuiApplication>
 #endif
 #include <QCommandLineParser>
+#include <QDir>
 #include <QIcon>
 #include <QQmlApplicationEngine>
+#include <QQmlContext>
 #include <QSqlDatabase>
 #include <QSqlError>
-#include <QSqlQuery>
+#include <QStandardPaths>
 #include <QUrl>
-#include <QtQml>
 #include <kontrast.h>
 
 const QString DRIVER(QStringLiteral("QSQLITE"));
